Crate dochy_compaction[−][src]
Re-exports
pub use crate::enc_dec::encode::encode; |
pub use crate::enc_dec::decode::decode; |
pub use crate::enc_dec::encode_to_vec::encode_to_vec; |
pub use crate::enc_dec::decode_from_slice::decode_from_slice; |
Modules
| basic_compaction | Compact integers and booleans |
| enc_dec | Details about the encoding and the decoding |
| kval_enum | Define the value type to serialize |
| string_compaction | Compact strings if the string represents a number |
| url_string | Convert bytes to the string which can be used as a part of URL and vice versa |